<?php
namespace FiloBlu\Storelocator\Setup;

use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\ModuleContextInterface;

class UpgradeSchema implements UpgradeSchemaInterface
{
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        //handle all possible upgrade versions

        if (!$context->getVersion()) {
            //no previous version found, installation, InstallSchema was just executed
            //be careful, since everything below is true for installation !
        }

        if (version_compare($context->getVersion(), '1.0.1') < 0) {

            //code to upgrade to 1.0.1
            // add fulltext index to permitt fulltext search in grid
            if ($setup->tableExists('filoblu_storelocator_stores')) {
                $setup->getConnection()->addIndex(
                    'filoblu_storelocator_stores', //table name
                    'title',    // index name
                    [
                        'title'   // filed or column name
                    ],
                    \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_FULLTEXT //type of index
                );
            }
        }

        if (version_compare($context->getVersion(), '1.0.2') < 0) {

            //code to upgrade to 1.0.2

            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'store_ids' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'nullable' => false,
                        'comment' => 'Store ids'
                    ],
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }

        if (version_compare($context->getVersion(), '1.0.3') < 0) {

            //code to upgrade to 1.0.3

            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'street' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        'nullable' => true,
                        'comment' => 'Street'
                    ],
                    'postcode' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        20,
                        'nullable' => true,
                        'comment' => 'Postcode'
                    ],
                    'city' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        100,
                        'nullable' => true,
                        'comment' => 'City'
                    ],
                    'country' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        100,
                        'nullable' => true,
                        'comment' => 'Country'
                    ],
                    'phone_1' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        30,
                        'nullable' => true,
                        'comment' => 'Phone 1'
                    ],
                    'phone_2' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        30,
                        'nullable' => true,
                        'comment' => 'Phone 2'
                    ],
                    'fax' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        30,
                        'nullable' => true,
                        'comment' => 'Fax'
                    ],
                    'email' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        100,
                        'nullable' => true,
                        'comment' => 'Email'
                    ],
                    'website_url' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        100,
                        'nullable' => true,
                        'comment' => 'Website Url'
                    ],
                    'additional_text' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        '2M',
                        'nullable' => true,
                        'comment' => 'Additional Text'
                    ],
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }

        if (version_compare($context->getVersion(), '1.0.4') < 0) {

            //code to upgrade to 1.0.4

            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'marker_image' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        'nullable' => true,
                        'comment' => 'Marker Image'
                    ],
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }

        if (version_compare($context->getVersion(), '1.0.5') < 0) {

            //code to upgrade to 1.0.5
            /**
             * Create table 'tags'
             */
            if (!$setup->tableExists('filoblu_storelocator_tags')) {
                $table = $setup->getConnection()->newTable(
                    $setup->getTable('filoblu_storelocator_tags'))
                    ->addColumn(
                        'tag_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                        'Tag Id'
                    )->addColumn(
                        'enabled',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        ['nullable' => false, 'default' => '0'],
                        'Enabled'
                    )->addColumn(
                        'name',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        ['nullable' => false],
                        'Name'
                    )->addColumn(
                        'description',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        ['nullable' => true],
                        'Description'
                    )->addColumn(
                        'image',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        [],
                        'Image'
                    )->setComment(
                        'tags list'
                    );
                $setup->getConnection()->createTable($table);
            }

            if (!$setup->tableExists('filoblu_storelocator_store_tag')) {
                $table = $setup->getConnection()
                    ->newTable($setup->getTable('filoblu_storelocator_store_tag'));
                $table->addColumn(
                    'store_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'unsigned' => true,
                        'nullable' => false,
                        'primary' => true,
                    ],
                    'Store Id'
                )
                    ->addColumn(
                        'tag_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        [
                            'unsigned' => true,
                            'nullable' => false,
                            'primary' => true,
                        ],
                        'Tag Id'
                    )
                    ->addIndex(
                        $setup->getIdxName('filoblu_storelocator_store_tag', ['store_id']),
                        ['store_id']
                    )
                    ->addIndex(
                        $setup->getIdxName('filoblu_storelocator_store_tag', ['tag_id']),
                        ['tag_id']
                    )
                    ->addForeignKey(
                        $setup->getFkName(
                            'filoblu_storelocator_store_tag',
                            'store_id',
                            'filoblu_storelocator_stores',
                            'store_id'
                        ),
                        'store_id',
                        $setup->getTable('filoblu_storelocator_stores'),
                        'store_id',
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                    )
                    ->addForeignKey(
                        $setup->getFkName(
                            'filoblu_storelocator_store_tag',
                            'tag_id',
                            'filoblu_storelocator_tags',
                            'tag_id'
                        ),
                        'tag_id',
                        $setup->getTable('filoblu_storelocator_tags'),
                        'tag_id',
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                    )
                    ->addIndex(
                        $setup->getIdxName(
                            'filoblu_storelocator_store_tag',
                            [
                                'store_id',
                                'tag_id'
                            ],
                            \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                        ),
                        [
                            'store_id',
                            'tag_id'
                        ],
                        [
                            'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                        ]
                    )
                    ->setComment('Store To Tag Link Table');
                $setup->getConnection()->createTable($table);
            }
        }

        if (version_compare($context->getVersion(), '1.0.6') < 0) {

            //code to upgrade to 1.0.6
            /**
             * Create table 'image'
             */
            if (!$setup->tableExists('filoblu_storelocator_images')) {
                $table = $setup->getConnection()->newTable(
                    $setup->getTable('filoblu_storelocator_images'))
                    ->addColumn(
                        'image_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                        'Image Id'
                    )->addColumn(
                        'enabled',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        ['nullable' => false, 'default' => '0'],
                        'Enabled'
                    )->addColumn(
                        'title',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        ['nullable' => false],
                        'Title'
                    )->addColumn(
                        'description',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        ['nullable' => true],
                        'Description'
                    )->addColumn(
                        'image',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        [],
                        'Image'
                    )->setComment(
                        'image list'
                    );
                $setup->getConnection()->createTable($table);
            }

            if (!$setup->tableExists('filoblu_storelocator_store_image')) {
                $table = $setup->getConnection()
                    ->newTable($setup->getTable('filoblu_storelocator_store_image'));
                $table->addColumn(
                    'store_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'unsigned' => true,
                        'nullable' => false,
                        'primary' => true,
                    ],
                    'Store Id'
                )
                    ->addColumn(
                        'image_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        [
                            'unsigned' => true,
                            'nullable' => false,
                            'primary' => true,
                        ],
                        'Image Id'
                    )
                    ->addColumn(
                        'position',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        [
                            'nullable' => false,
                            'default' => '0'
                        ],
                        'Position'
                    )
                    ->addIndex(
                        $setup->getIdxName('filoblu_storelocator_store_image', ['store_id']),
                        ['store_id']
                    )
                    ->addIndex(
                        $setup->getIdxName('filoblu_storelocator_store_image', ['image_id']),
                        ['image_id']
                    )
                    ->addForeignKey(
                        $setup->getFkName(
                            'filoblu_storelocator_store_image',
                            'store_id',
                            'filoblu_storelocator_stores',
                            'store_id'
                        ),
                        'store_id',
                        $setup->getTable('filoblu_storelocator_stores'),
                        'store_id',
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                    )
                    ->addForeignKey(
                        $setup->getFkName(
                            'filoblu_storelocator_store_image',
                            'image_id',
                            'filoblu_storelocator_images',
                            'image_id'
                        ),
                        'image_id',
                        $setup->getTable('filoblu_storelocator_images'),
                        'image_id',
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                    )
                    ->addIndex(
                        $setup->getIdxName(
                            'filoblu_storelocator_store_image',
                            [
                                'store_id',
                                'image_id'
                            ],
                            \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                        ),
                        [
                            'store_id',
                            'image_id'
                        ],
                        [
                            'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                        ]
                    )
                    ->setComment('Store To Image Link Table');
                $setup->getConnection()->createTable($table);
            }
        }

        if (version_compare($context->getVersion(), '1.0.7') < 0) {

            //code to upgrade to 1.0.7
            /**
             * Create table 'working-times'
             */

            if (!$setup->tableExists('filoblu_storelocator_store_workingtimes')) {
                $table = $setup->getConnection()
                    ->newTable($setup->getTable('filoblu_storelocator_store_workingtimes'));
                $table
                    ->addColumn(
                        'workingtime_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                        'Working Times Id'
                    )
                    ->addColumn(
                    'store_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'unsigned' => true,
                        'nullable' => false,
                        'primary' => true,
                    ],
                    'Store Id'
                )
                    ->addColumn(
                        'day',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        [
                            'unsigned' => true,
                            'nullable' => false,
                            'primary' => true,
                        ],
                        'Day (1=Monday,2=Tuesday..)'
                    )
                    ->addColumn(
                        'period',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        [
                            'unsigned' => true,
                            'nullable' => false,
                            'primary' => true,
                        ],
                        'Period (Morning/Afternoon)'
                    )
                    ->addColumn(
                        'from',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TIMESTAMP,
                        null,
                        [
                            'nullable' => true,

                        ],
                        'Open From'
                    )
                    ->addColumn(
                        'to',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TIMESTAMP,
                        null,
                        [
                            'nullable' => true,

                        ],
                        'Open To'
                    )
                    ->addColumn(
                        'closed',
                        \Magento\Framework\DB\Ddl\Table::TYPE_BOOLEAN,
                        null,
                        [
                            'nullable' => false,
                            'default' => false
                        ],
                        'Closed'
                    )
                    ->addIndex(
                        $setup->getIdxName('filoblu_storelocator_store_workingtimes', ['store_id']),
                        ['store_id']
                    )
                    ->addIndex(
                        $setup->getIdxName('filoblu_storelocator_store_workingtimes', ['day']),
                        ['day']
                    )
                    ->addIndex(
                        $setup->getIdxName('filoblu_storelocator_store_workingtimes', ['period']),
                        ['period']
                    )
                    ->addForeignKey(
                        $setup->getFkName(
                            'filoblu_storelocator_store_workingtimes',
                            'store_id',
                            'filoblu_storelocator_stores',
                            'store_id'
                        ),
                        'store_id',
                        $setup->getTable('filoblu_storelocator_stores'),
                        'store_id',
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                        \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                    )
                    ->addIndex(
                        $setup->getIdxName(
                            'filoblu_storelocator_store_workingtimes',
                            [
                                'store_id',
                                'day',
                                'period',
                            ],
                            \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                        ),
                        [
                            'store_id',
                            'day',
                            'period',
                        ],
                        [
                            'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                        ]
                    )
                    ->setComment('Store To Working Times Link Table');
                $setup->getConnection()->createTable($table);
            }
        }

        if (version_compare($context->getVersion(), '1.0.8') < 0) {

            //code to upgrade to 1.0.8
            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'gmb_cat' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        'nullable' => true,
                        'comment' => 'Google My Business Category'
                    ]
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }

        if (version_compare($context->getVersion(), '1.0.9') < 0) {

            //code to upgrade to 1.0.9
            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'gmb_language_code' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        50,
                        'nullable' => true,
                        'comment' => 'Google My Business Language Code'
                    ]
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }
        if (version_compare($context->getVersion(), '1.0.10') < 0) {

            //code to upgrade to 1.0.10
            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'gmb_location_name' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        150,
                        'nullable' => true,
                        'comment' => 'Google My Business Location Name'
                    ]
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }
        if (version_compare($context->getVersion(), '1.1.0') < 0) {

            //code to upgrade to 1.1.0
            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'region' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        255,
                        'nullable' => true,
                        'comment' => 'State/Province'
                    ],
                    'region_id' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        'nullable' => true,
                        'comment' => 'State/Province ID'
                    ]
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }

        if (version_compare($context->getVersion(), '1.2.1') < 0) {

            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'is_enabled_for_pickup_in_store' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        'length' => 1,
                        'nullable' => true,
                        'default' => 0,
                        'comment' => 'Is Enabled For Pickup In Store'
                    ]
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }

        if (version_compare($context->getVersion(), '1.2.4') < 0) {

            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'url_key' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'length' => 100,
                        'nullable' => true,
                        'comment' => 'Url Key'
                    ]
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }

                $setup->getConnection()->addIndex(
                    $setup->getTable('filoblu_storelocator_stores'),
                    $setup->getIdxName('url_key', ['url_key']),
                    ['url_key']
                );
            }
        }

        if (version_compare($context->getVersion(), '1.2.5') < 0) {

            // Get module table
            $tableName = $setup->getTable('filoblu_storelocator_stores');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $columns = [
                    'store_code' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'length' => 100,
                        'nullable' => true,
                        'comment' => 'Store Code'
                    ]
                ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition) {
                    $connection->addColumn($tableName, $name, $definition);
                }

                $setup->getConnection()->addIndex(
                    $setup->getTable('filoblu_storelocator_stores'),
                    $setup->getIdxName('store_code', ['store_code']),
                    ['store_code']
                );
            }
        }

        if (version_compare($context->getVersion(), '1.2.6') < 0) {

            // Change columns type
            $connection = $setup->getConnection();

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'store_ids',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 100
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'street',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 255
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'postcode',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 10
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'city',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 100
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'country',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 3
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'country',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 3
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'country',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 3
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'phone_1',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 30
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'phone_2',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 30
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'fax',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 30
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'email',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 100
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'website_url',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 50
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'marker_image',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 255
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'gmb_cat',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 100
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'gmb_language_code',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 10
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'gmb_location_name',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 100
                ]
            );

            $connection->modifyColumn(
                $setup->getTable('filoblu_storelocator_stores'),
                'region',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'length' => 100
                ]
            );
        }

        $setup->endSetup();
    }
}
